@@ -29,6 +29,9 @@
  *
  * Authors: Federico Mena <federico@nuclecu.unam.mx>
  */
+
+#define _XOPEN_SOURCE 500
+
 #include <config.h>
 #include <glib.h>
 #include <sys/param.h>
@@ -42,15 +45,7 @@
 #include <libgnome/gnome-macros.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkdnd.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtkfilesel.h>
-#include <gtk/gtkfilechooserdialog.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkdialog.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtksignal.h>
+#include <gtk/gtk.h>
 
 /* Must be before all other gnome includes!! */
 #include <glib/gi18n-lib.h>
@@ -457,6 +452,9 @@ browse_dialog_ok (GtkWidget *widget, gpointer data)
 	else
 		locale_filename = g_strdup (gtk_file_selection_get_filename (GTK_FILE_SELECTION (fw)));
 
+	if (!locale_filename)
+		return;
+
 	utf8_filename = g_filename_to_utf8 (locale_filename, -1, NULL,
 					    NULL, NULL);
 	g_free (locale_filename);
